==> qtmobility_1.1.0.orig.tar.gz: qt-mobility-opensource-src-1.1.0/plugins/declarative/contacts/filters/qdeclarativecontactunionfilter_p.h <==
/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in 
** accordance with the Qt Commercial License Agreement provided with
** the Software or, alternatively, in accordance with the terms
** contained in a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QDECLARATIVECONTACTUNIONFILTER_H
#define QDECLARATIVECONTACTUNIONFILTER_H

#include "qdeclarativecontactfilter_p.h"
#include "qcontactunionfilter.h"

#include <QDeclarativeListProperty>

class QDeclarativeContactUnionFilter : public QDeclarativeContactFilter
{
    Q_OBJECT
    Q_PROPERTY(QDeclarativeListProperty<QDeclarativeContactFilter> filters READ filters NOTIFY valueChanged)
    Q_CLASSINFO("DefaultProperty", "filters")

public:
    QDeclarativeListProperty<QDeclarativeContactFilter> filters()
    {
        return QDeclarativeListProperty<QDeclarativeContactFilter>(this, m_filters);
    }

    QContactFilter filter()
    {
        return d;
    }

public slots:
    void setFilters()
    {
        QList<QContactFilter> filters;
        foreach (QDeclarativeContactFilter* f, m_filters) {
            filters << f->filter();
        }
        d.setFilters(filters);
    }

signals:
    void valueChanged();


private:
    QList<QDeclarativeContactFilter*> m_filters;
    QContactUnionFilter d;
};

QML_DECLARE_TYPE(QDeclarativeContactUnionFilter)

#endif

==> qtmobility_1.2.0.orig.tar.gz: qt-mobility-opensource-src-1.2.0/plugins/declarative/contacts/filters/qdeclarativecontactunionfilter_p.h <==
/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:LGPL$
** No Commercial Usage
** This file contains pre-release code and may not be distributed.
** You may use this file in accordance with the terms and conditions
** contained in the Technology Preview License Agreement accompanying
** this package.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**
**
**
**
**
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QDECLARATIVECONTACTUNIONFILTER_H
#define QDECLARATIVECONTACTUNIONFILTER_H

#include "qdeclarativecontactfilter_p.h"
#include "qcontactunionfilter.h"

#include <QDeclarativeListProperty>

class QDeclarativeContactUnionFilter : public QDeclarativeContactFilter
{
    Q_OBJECT
    Q_PROPERTY(QDeclarativeListProperty<QDeclarativeContactFilter> filters READ filters NOTIFY valueChanged())
    Q_CLASSINFO("DefaultProperty", "filters")

public:
    QDeclarativeContactUnionFilter(QObject* parent = 0)
        :QDeclarativeContactFilter(parent)
    {
        connect(this, SIGNAL(valueChanged()), SIGNAL(filterChanged()));
    }
    QDeclarativeListProperty<QDeclarativeContactFilter> filters()
    {
        return QDeclarativeListProperty<QDeclarativeContactFilter>(this, m_filters);
    }

    QContactFilter filter() const
    {
        QList<QContactFilter> filters;
        foreach (QDeclarativeContactFilter* f, m_filters) {
            filters << f->filter();
        }
        QContactUnionFilter f;
        f.setFilters(filters);
        return f;
    }
signals:
    void valueChanged();


private:
    QList<QDeclarativeContactFilter*> m_filters;
};

QML_DECLARE_TYPE(QDeclarativeContactUnionFilter)

#endif
